@@ -33,6 +33,7 @@ def create_knada_nb_pod_operator(
     delete_on_finish: bool = True,
     startup_timeout_seconds: int = 360,
     retry_delay: timedelta = timedelta(seconds=5),
+    nls_lang: str = "NORWEGIAN_NORWAY.AL32UTF8"
 ):
     """ Factory function for creating KubernetesPodOperator for executing knada jupyter notebooks
 
@@ -51,6 +52,7 @@ def create_knada_nb_pod_operator(
     :param delete_on_finish: bool: Whether to delete pod on completion
     :param startup_timeout_seconds: int: pod startup timeout
     :param retry_delay: timedelta: Time inbetween retries, default 5 seconds
+    :param nls_lang: str: Configure locale and character sets with NLS_LANG environment variable in k8s pod, defaults to Norwegian
     :return: KubernetesPodOperator
     """
 
@@ -60,15 +62,18 @@ def create_knada_nb_pod_operator(
         "NOTEBOOK_NAME": Path(nb_path).name,
         "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
         "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
+        "DATAVERK_SECRETS_FROM_API": "true",
         "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
         "https_proxy": os.environ["HTTPS_PROXY"],
         "NO_PROXY": os.environ["NO_PROXY"],
         "no_proxy": os.environ["NO_PROXY"],
+        "TZ": os.environ["TZ"],
         "VKS_VAULT_ADDR": os.environ["VKS_VAULT_ADDR"],
         "VKS_AUTH_PATH": os.environ["VKS_AUTH_PATH"],
         "VKS_KV_PATH": os.environ["VKS_KV_PATH"],
         "K8S_SERVICEACCOUNT_PATH": os.environ["K8S_SERVICEACCOUNT_PATH"],
-        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH
+        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH,
+        "NLS_LANG": nls_lang
     }
 
     if extra_envs:
@@ -149,6 +154,7 @@ def create_knada_python_pod_operator(
     delete_on_finish: bool = True,
     startup_timeout_seconds: int = 360,
     retry_delay: timedelta = timedelta(seconds=5),
+    nls_lang: str = "NORWEGIAN_NORWAY.AL32UTF8"
 ):
     """ Factory function for creating KubernetesPodOperator for executing knada python scripts
 
@@ -166,6 +172,7 @@ def create_knada_python_pod_operator(
     :param delete_on_finish: bool: Whether to delete pod on completion
     :param startup_timeout_seconds: int: pod startup timeout
     :param retry_delay: timedelta: Time inbetween retries, default 5 seconds
+    :param nls_lang: str: Configure locale and character sets with NLS_LANG environment variable in k8s pod, defaults to Norwegian
     :return: KubernetesPodOperator
     """
 
@@ -174,15 +181,18 @@ def create_knada_python_pod_operator(
         "NOTEBOOK_NAME": Path(script_path).name,
         "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
         "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
+        "DATAVERK_SECRETS_FROM_API": "true",
         "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
         "https_proxy": os.environ["HTTPS_PROXY"],
         "NO_PROXY": os.environ["NO_PROXY"],
         "no_proxy": os.environ["NO_PROXY"],
+        "TZ": os.environ["TZ"],
         "VKS_VAULT_ADDR": os.environ["VKS_VAULT_ADDR"],
         "VKS_AUTH_PATH": os.environ["VKS_AUTH_PATH"],
         "VKS_KV_PATH": os.environ["VKS_KV_PATH"],
         "K8S_SERVICEACCOUNT_PATH": os.environ["K8S_SERVICEACCOUNT_PATH"],
-        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH
+        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH,
+        "NLS_LANG": nls_lang
     }
 
     if extra_envs:
@@ -530,7 +540,7 @@ def create_knada_bq_operator(
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_GCLOUD_IMAGE", "google/cloud-sdk:319.0.0"),
         env_vars={
-            "GOOGLE_APPLICATION_CREDENTIALS": f"{POD_WORKSPACE_DIR}/creds.json",
+            "GOOGLE_APPLICATION_CREDENTIALS": f"{CREDS_DIR}/creds.json",
             "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
             "https_proxy": os.environ["HTTPS_PROXY"],
             "NO_PROXY": os.environ["NO_PROXY"],
